@@ -72,7 +72,7 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
             name of the current action selected
         """
         # Recovering the action selected by the user
-        action_type = self.c_operation.currentText()
+        action_type = self.c_operation.currentText().split(" over")[0]
 
         # Formatting the string to have the right syntax
         if action_type == "slice":
@@ -165,6 +165,9 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
         elif operation_type == "list":
             operation_type = "overlay"
 
+        else:
+            operation_type += " over " + self.name
+
         # Setting operation combobox to the right operation
         self.c_operation.setCurrentIndex(self.c_operation.findText(operation_type))
 
@@ -227,6 +230,9 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
             # Setting the initial value of the floatEdit to the minimum inside the axis
             self.lf_value.setValue(min(self.axis_value))
 
+            # Setting the axis unit
+            self.in_unit.setText("[" + self.axis.unit + "]")
+
             # Setting the slider by giving the number of index according to the size of the axis
             self.slider.setMinimum(0)
             self.slider.setMaximum(len(self.axis_value) - 1)
@@ -250,14 +256,21 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
         self.set_name(self.axis_name)
 
         self.c_operation.blockSignals(True)
-        operation_list = OPERATION_LIST.copy()
+        operation_list = [
+            ope + " over " + self.name if ope in type_extraction_dict else ope
+            for ope in OPERATION_LIST
+        ]
 
         # Remove slice for string axes
-        if self.axis.is_overlay:
+        if self.axis.is_components:
             operation_list.remove("slice")
         else:
             self.set_slider_floatedit()
 
+        # Remove overlay for non is_components axes
+        if not self.axis.is_components:
+            operation_list.remove("overlay")
+
         # Remove fft slice for non fft axes
         if not self.axis_name in fft_dict:
             operation_list.remove("slice (fft)")
@@ -296,24 +309,27 @@ class WSliceOperator(Ui_WSliceOperator, QWidget):
             a WSliceOperator object
         """
         # Recovering the operation selected
-        extraction_selected = self.c_operation.currentText()
+        extraction_selected = self.c_operation.currentText().split(" over")[0]
 
         # If the operation selected is a slice, then we show the slider and the floatEdit
         if extraction_selected == "slice" or extraction_selected == "slice (fft)":
             self.set_slider_floatedit()
             self.lf_value.show()
+            self.in_unit.show()
             self.slider.show()
             self.b_action.hide()
             self.refreshNeeded.emit()
         # If the operation selected is overlay then we show the related button
         elif extraction_selected == "overlay":
             self.lf_value.hide()
+            self.in_unit.hide()
             self.slider.hide()
             self.b_action.show()
             self.b_action.setText("Overlay")
             self.refreshNeeded.emit()
         else:
             self.lf_value.hide()
+            self.in_unit.hide()
             self.slider.hide()
             self.b_action.hide()
             self.refreshNeeded.emit()
