@@ -75,7 +75,7 @@ def get_data_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
                 "freqs",
                 "wavenumber",
             ]:
-                symmetries = self.axes[index].symmetries
+                symmetries = self.axes[index].symmetries.copy()
             else:
                 symmetries = dict()
             Axes.append(
@@ -84,7 +84,7 @@ def get_data_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
                     unit=ax_unit,
                     values=axis_values,
                     is_components=is_components,
-                    normalizations=self.axes[index].normalizations,
+                    normalizations=self.axes[index].normalizations.copy(),
                     symmetries=symmetries,
                 ).to_linspace()
             )
@@ -107,6 +107,6 @@ def get_data_along(self, *args, unit="SI", is_norm=False, axis_data=[]):
         symbol=self.symbol,
         axes=Axes,
         values=values,
-        normalizations=self.normalizations,
+        normalizations=self.normalizations.copy(),
         is_real=self.is_real,
     )
